==> release-1.6.tar.gz: website/docs/getting-started-guides/stackpoint.md <==
---
assignees:
- baldwinspc
title: Running Kubernetes on Multiple Clouds with Stackpoint.io
---

* TOC
{:toc}


## Introduction

StackPointCloud is the universal control plane for Kubernetes Anywhere.  StackPointCloud allows you to deploy and manage a Kubernetes cluster to the cloud provider of your choice in 3 steps using a web-based interface.

## AWS

To create a Kubernetes cluster on AWS, you will need an Access Key ID and a Secret Access Key from AWS.

### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select Amazon Web Services (AWS).

### Configure Your Provider

Add your Access Key ID and a Secret Access Key from AWS. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 

### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on AWS, [consult the  Kubernetes documentation](http://kubernetes.io/docs/getting-started-guides/aws/).




## GCE

To create a Kubernetes cluster on GCE, you will need the Service Account JSON Data from Google.


### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select Google Compute Engine (GCE).

### Configure Your Provider

Add your Service Account JSON Data from Google. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 

### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on GCE, [consult the  Kubernetes documentation](http://kubernetes.io/docs/getting-started-guides/gce).





## GKE

To create a Kubernetes cluster on GKE, you will need the Service Account JSON Data from Google.

### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select Google Container Engine (GKE).

### Configure Your Provider

Add your Service Account JSON Data from Google. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 


### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on GKE, consult [the official documentation](http://kubernetes.io/docs/).





## DigitalOcean

To create a Kubernetes cluster on DigitalOcean, you will need a DigitalOcean API Token.

### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select DigitalOcean.

### Configure Your Provider

Add your DigitalOcean API Token. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 

### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on DigitalOcean, consult [the official documentation](http://kubernetes.io/docs/).





## Microsoft Azure

To create a Kubernetes cluster on Microsoft Azure, you will need an Azure Subscription ID, Username/Email, and Password.

### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select Microsoft Azure.

### Configure Your Provider

Add your Azure Subscription ID, Username/Email, and Password. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 


### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on Azure, [consult the  Kubernetes documentation](http://kubernetes.io/docs/getting-started-guides/azure/).





## Packet

To create a Kubernetes cluster on Packet, you will need a Packet API Key.

### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select Packet.

### Configure Your Provider

Add your Packet API Key. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 

### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on Packet, consult [the official documentation](http://kubernetes.io/docs/).

==> release-1.7.tar.gz: website/docs/getting-started-guides/stackpoint.md <==
---
approvers:
- baldwinspc
title: Running Kubernetes on Multiple Clouds with Stackpoint.io
---

* TOC
{:toc}


## Introduction

StackPointCloud is the universal control plane for Kubernetes Anywhere.  StackPointCloud allows you to deploy and manage a Kubernetes cluster to the cloud provider of your choice in 3 steps using a web-based interface.

## AWS

To create a Kubernetes cluster on AWS, you will need an Access Key ID and a Secret Access Key from AWS.

### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select Amazon Web Services (AWS).

### Configure Your Provider

Add your Access Key ID and a Secret Access Key from AWS. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 

### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on AWS, [consult the  Kubernetes documentation](/docs/getting-started-guides/aws/).




## GCE

To create a Kubernetes cluster on GCE, you will need the Service Account JSON Data from Google.


### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select Google Compute Engine (GCE).

### Configure Your Provider

Add your Service Account JSON Data from Google. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 

### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on GCE, [consult the  Kubernetes documentation](/docs/getting-started-guides/gce/).





## GKE

To create a Kubernetes cluster on GKE, you will need the Service Account JSON Data from Google.

### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select Google Container Engine (GKE).

### Configure Your Provider

Add your Service Account JSON Data from Google. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 


### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on GKE, consult [the official documentation](/docs/home/).





## DigitalOcean

To create a Kubernetes cluster on DigitalOcean, you will need a DigitalOcean API Token.

### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select DigitalOcean.

### Configure Your Provider

Add your DigitalOcean API Token. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 

### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on DigitalOcean, consult [the official documentation](/docs/home/).





## Microsoft Azure

To create a Kubernetes cluster on Microsoft Azure, you will need an Azure Subscription ID, Username/Email, and Password.

### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select Microsoft Azure.

### Configure Your Provider

Add your Azure Subscription ID, Username/Email, and Password. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 


### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on Azure, [consult the  Kubernetes documentation](/docs/getting-started-guides/azure/).





## Packet

To create a Kubernetes cluster on Packet, you will need a Packet API Key.

### Choose a Provider

Log in to [stackpoint.io](https://stackpoint.io) with a GitHub, Google, or Twitter account.

Click **+ADD A CLUSTER NOW**.

Click to select Packet.

### Configure Your Provider

Add your Packet API Key. Select your default StackPointCloud SSH keypair, or click **ADD SSH KEY** to add a new keypair.

Click **SUBMIT** to submit the authorization information.

### Configure Your Cluster

Choose any extra options you may want to include with your cluster, then click **SUBMIT** to create the cluster. 

### Running the Cluster

You can monitor the status of your cluster and suspend or delete it from [your stackpoint.io dashboard](https://stackpoint.io/#/clusters).

For information on using and managing a Kubernetes cluster on Packet, consult [the official documentation](/docs/home/).
